@@ -5,4 +5,4 @@ ENV_NPU_DEVNAME = "NPU_DEVNAME"
 ENV_XDG_STATE_HOME = "XDG_STATE_HOME"
 
 # Default NPU device
-DEFAULT_DEVNAME = "npu0pe0"
+DEFAULT_DEVNAME = "npu0pe0-1"
