@@ -78,7 +78,9 @@ def _create_session_options(
         LIBNUX.nux_session_option_set_worker_num(options, worker_num)
     if compile_config:
         compile_config = yaml.dump(compile_config).encode()
-        LIBNUX.nux_session_option_set_compiler_config(options, compile_config)
+        err = LIBNUX.nux_session_option_set_compiler_config(options, compile_config)
+        if is_err(err):
+            raise into_exception(err)
     if compiler_log:
         compiler_log = str(compiler_log).encode()
         LIBNUX.nux_session_option_set_compiler_log_path(options, compiler_log)
@@ -199,7 +201,7 @@ class Session(Model):
 
     def close(self):
         """Close the session and release all resources belonging to the session"""
-        if self.ref:
+        if hasattr(self, "ref") and self.ref:
             LIBNUX.nux_session_destroy(self.ref)
             self.ref = None
 
